import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="pwiener_pypi_sample",
    version="1.0.1",
    packages=["pypi_sample"],
    long_description=README,
)
